@@ -29,6 +29,13 @@ CONDA_BUCKET_NS = os.environ.get("CONDA_BUCKET_NS", "id19sfcrra6z")
 OCI_RESOURCE_PRINCIPAL_RPT_ENDPOINT = os.environ.get(
     "OCI_RESOURCE_PRINCIPAL_RPT_ENDPOINT"
 )
+COMPARTMENT_OCID = NB_SESSION_COMPARTMENT_OCID or JOB_RUN_COMPARTMENT_OCID
+MD_OCID = os.environ.get("MD_OCID")
+DATAFLOW_RUN_OCID = os.environ.get("DATAFLOW_RUN_ID")
+RESOURCE_OCID = (
+    NB_SESSION_OCID or JOB_RUN_OCID or MD_OCID
+)  # We can add DATAFLOW_RUN_OCID here. Needs impact analysis
+NO_CONTAINER = os.environ.get("NO_CONTAINER")
 
 
 @contextlib.contextmanager
